@@ -1,5 +1,5 @@
 package Pod::Autopod; ## Generates pod documentation by analysing perl modules.
-$Pod::Autopod::VERSION = '1.202';
+$Pod::Autopod::VERSION = '1.203';
 use 5.006; #Pod::Abstract uses features of 5.6
 use FileHandle;
 use strict;
@@ -345,7 +345,7 @@ my $self=shift;
 my $file=shift;
 my $pod=$self->getPod();
 
-	if ($file=~ m/\.pm$|\.pl$|\.cgi$/i){ ## target is pm or pl or cgi file, so add perl-code 
+	if ($file=~ m/\.(pm|pl|cgi)$/i){ ## target is pm or pl or cgi file, so add perl-code 
 		my $text=$self->getPerlCode();
 		$text.="\n".$self->{'BORDER'}."\n\n$pod";
 		$self->_putFile($file,$text);
